NAME

Nobody::PP - Pretty-printer for Perl data structures

SYNOPSIS

use Nobody::PP;

dd({ key => "value", list => [1, 2, 3] });   # print to STDOUT
ee({ key => "value" });                        # print to STDERR
my $str = pp({ key => "value" });              # return as string
ddx($thing);                                   # print with file:line prefix

DESCRIPTION

Nobody::PP is a pretty-printer for Perl data structures, providing compact, readable output suitable for debugging.

EXPORTS

dd, ddx, ee, eex, pp, ppx, quote, qquote, loc are exported by default.

FUNCTIONS

pp( @data )

Returns a string representation of @data.

dd( @data )

Prints pp(@data) to STDOUT followed by a newline.

ee( @data )

Prints pp(@data) to STDERR followed by a newline.

ppx( @data )

Returns pp(@data) prefixed with the caller's file and line number.

ddx( @data )

Prints ppx(@data) to STDOUT.

eex( @data )

Prints ppx(@data) to STDERR.

loc( @strings )

Returns a string of the form file:line:@strings identifying the call site.

quote( $string )

Returns $string as a single-quoted Perl string literal.

qquote( $string )

Returns $string as a double-quoted Perl string literal (via Data::Dumper).

ACKNOWLEDGEMENTS

This module is derived from Data::Dump by Gisle Aas. Thank him for the features; blame me for the bugs.

AUTHOR

Rich Paul, <nobody at cpan.org>

LICENSE

This module is free software; you can redistribute it and/or modify it under the same terms as Perl itself.